summaryrefslogtreecommitdiffstats
path: root/kmail/kmmessage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmessage.h')
-rw-r--r--kmail/kmmessage.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kmail/kmmessage.h b/kmail/kmmessage.h
index ebc8c78ef..ffae3ff09 100644
--- a/kmail/kmmessage.h
+++ b/kmail/kmmessage.h
@@ -150,13 +150,13 @@ public:
}
/** Mark the message as deleted */
- void del() { setqStatus(KMMsgStatusDeleted); }
+ void del() { seStatus(KMMsgStatusDeleted); }
/** Undelete the message. Same as touch */
- void undel() { setqStatus(KMMsgStatusOld); }
+ void undel() { seStatus(KMMsgStatusOld); }
/** Touch the message - mark it as read */
- void touch() { setqStatus(KMMsgStatusOld); }
+ void touch() { seStatus(KMMsgStatusOld); }
/** Create a new message that is a reply to this message, filling all
required header fields with the proper values. The returned message
@@ -210,9 +210,9 @@ public:
void sanitizeHeaders( const TQStringList& whiteList = TQStringList() );
/** Parse the string and create this message from it. */
- void fromDwString(const DwString& str, bool setqStatus=false);
- void fromString(const TQCString& str, bool setqStatus=false);
- void fromByteArray(const TQByteArray & ba, bool setqStatus=false);
+ void fromDwString(const DwString& str, bool seStatus=false);
+ void fromString(const TQCString& str, bool seStatus=false);
+ void fromByteArray(const TQByteArray & ba, bool seStatus=false);
/** Return the entire message contents in the DwString. This function
is *fast* even for large message since it does *not* involve a
@@ -243,7 +243,7 @@ public:
TQCString headerAsSendableString() const;
/**
- * Remove all private header fields: *tqStatus: and X-KMail-*
+ * Remove all private header fields: *Status: and X-KMail-*
**/
void removePrivateHeaderFields();
@@ -822,11 +822,11 @@ public:
ulong UID() const;
void setUID(ulong uid);
- /** tqStatus of the message. */
- KMMsgtqStatus status() const { return mtqStatus; }
+ /** Status of the message. */
+ KMMsgStatus status() const { return mStatus; }
/** Set status and mark dirty. */
- void setqStatus(const KMMsgtqStatus status, int idx = -1);
- void setqStatus(const char* s1, const char* s2=0) { KMMsgBase::setqStatus(s1, s2); }
+ void seStatus(const KMMsgStatus status, int idx = -1);
+ void seStatus(const char* s1, const char* s2=0) { KMMsgBase::seStatus(s1, s2); }
/** Set encryption status of the message. */
void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
@@ -844,11 +844,11 @@ public:
KMMsgMDNSentState mdnSentState() const { return mMDNSentState; }
- /** Links this message to @p aMsg, setting link type to @p atqStatus. */
- void link(const KMMessage *aMsg, KMMsgtqStatus atqStatus);
+ /** Links this message to @p aMsg, setting link type to @p aStatus. */
+ void link(const KMMessage *aMsg, KMMsgStatus aStatus);
/** Returns the information for the Nth link into @p retMsg
- * and @p retqStatus. */
- void getLink(int n, ulong *retMsgSerNum, KMMsgtqStatus *retqStatus) const;
+ * and @p reStatus. */
+ void getLink(int n, ulong *retMsgSerNum, KMMsgStatus *reStatus) const;
/** Convert wildcards into normal string */
TQString formatString(const TQString&) const;